@@ -39,6 +39,7 @@
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
+#define MOZILLA_INTERNAL_API
 #include "nsEnigContentHandler.h"
 #include "mimedummy.h"
 #include "mimeenig.h"
@@ -50,6 +51,7 @@
 #include "nsIThread.h"
 #include "nsIMimeObjectClassAccess.h"
 #include "nsMsgMimeCID.h"
+#undef MOZILLA_INTERNAL_API
 
 MimeContainerClass* mimeContainerClassP = NULL;
 
@@ -88,8 +90,8 @@ nsEnigContentHandler::nsEnigContentHandler()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigContentHandler:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsEnigContentHandler:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 }
 
@@ -100,8 +102,8 @@ nsEnigContentHandler::~nsEnigContentHandler()
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
   rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigContentHandler:: >>>>>>>>> DTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  DEBUG_LOG(("nsEnigContentHandler:: >>>>>>>>> DTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
 }
