@@ -22,7 +22,7 @@
  * Patrick Brunschwig <patrick.brunschwig@gmx.net>
  *
  * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or 
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
  * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
  * in which case the provisions of the GPL or the LGPL are applicable instead
  * of those above. If you wish to allow use of your version of this file only
@@ -35,11 +35,11 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-// Logging of debug output 
+// Logging of debug output
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
-#define MOZILLA_INTERNAL_API
+#include "enigmail.h"
 #include "mimeenig.h"
 #include "nsEnigModule.h"
 #include "nsEnigMimeService.h"
@@ -91,7 +91,7 @@ nsEnigMimeService::nsEnigMimeService()
 
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeService:: <<<<<<<<< CTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -112,7 +112,7 @@ nsEnigMimeService::nsEnigMimeService()
     nsCOMPtr<nsIComponentRegistrar> registrar;
     rv = NS_GetComponentRegistrar(getter_AddRefs(registrar));
     if (NS_FAILED(rv)) return;
-        
+
     rv = registrar->RegisterFactory(info.mCID, info.mDescription,
                                              info.mContractID, factory);
     if (NS_SUCCEEDED(rv)) {
@@ -127,7 +127,7 @@ nsEnigMimeService::~nsEnigMimeService()
   nsresult rv;
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeService:: >>>>>>>>> DTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -166,7 +166,7 @@ nsEnigMimeService::Init()
   nsCOMPtr<nsIGenericFactory> factory;
   rv = NS_NewGenericFactory(getter_AddRefs(factory), &info);
   if (NS_FAILED(rv)) return rv;
-  
+
   nsCOMPtr<nsIComponentRegistrar> registrar;
   rv = NS_GetComponentRegistrar(getter_AddRefs(registrar));
   if (NS_FAILED(rv)) return rv;
@@ -289,3 +289,38 @@ nsEnigMimeService::IsEncrypted(const nsACString & uri, PRBool *_retval)
   *_retval = (mEncryptedURIs.IndexOf(nsCString(uri)) != -1);
   return NS_OK;
 }
+
+NS_IMETHODIMP
+nsEnigMimeService::Sleep(PRUint32 miliSeconds)
+{
+  // Sleep for the specified amount of miliseconds
+  PR_Sleep(miliSeconds);
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsEnigMimeService::GetGpgPathFromRegistry(nsAString& retval) {
+
+#ifdef XP_WIN
+  HKEY key;
+	DWORD type, length;
+	unsigned char gpgProg[MAX_PATH];
+
+	if (::RegOpenKeyEx(HKEY_LOCAL_MACHINE, "Software\\GNU\\GNUPG", 0, KEY_READ, &key) != ERROR_SUCCESS) {
+    return NS_ERROR_FAILURE;
+  }
+
+	if (::RegQueryValueEx(key, "Install Directory", 0, &type, gpgProg, &length) != ERROR_SUCCESS) {
+    return NS_ERROR_FAILURE;
+  }
+	// printf("length: %d\nstring: %s\n", length, gpgProg);
+	nsAutoString gpgPath;
+	gpgPath.AssignWithConversion((char*)gpgProg);
+	retval = gpgPath;
+	return NS_OK;
+
+#else
+  return NS_ERROR_FAILURE;
+#endif
+
+}
