@@ -35,11 +35,11 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-// Logging of debug output 
+// Logging of debug output
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
-#define MOZILLA_INTERNAL_API
+#include "enigmail.h"
 #include "nspr.h"
 #include "nsCOMPtr.h"
 #include "nsString.h"
@@ -48,6 +48,7 @@
 #include "nsNetCID.h"
 #include "nsIPrompt.h"
 #include "nsIMsgWindow.h"
+#include "nsIDOMWindow.h"
 #include "nsIMimeMiscStatus.h"
 #include "nsIEnigMimeHeaderSink.h"
 #include "nsIThread.h"
@@ -113,7 +114,7 @@ nsEnigMimeVerify::nsEnigMimeVerify()
 
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeVerify:: <<<<<<<<< CTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -125,7 +126,7 @@ nsEnigMimeVerify::~nsEnigMimeVerify()
   nsresult rv;
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
+  rv = ENIG_GET_THREAD(myThread);
   DEBUG_LOG(("nsEnigMimeVerify:: >>>>>>>>> DTOR(%p): myThread=%p\n",
          this, myThread.get()));
 #endif
@@ -139,7 +140,9 @@ nsEnigMimeVerify::~nsEnigMimeVerify()
 ///////////////////////////////////////////////////////////////////////////////
 
 NS_IMETHODIMP
-nsEnigMimeVerify::Init(nsIURI* aURI, nsIMsgWindow* msgWindow,
+nsEnigMimeVerify::Init(nsIDOMWindow* window,
+                       nsIURI* aURI,
+                       nsIMsgWindow* msgWindow,
                        const nsACString& msgUriSpec,
                        PRBool rfc2015,
                        PRBool isSubPart)
@@ -199,12 +202,14 @@ nsEnigMimeVerify::Init(nsIURI* aURI, nsIMsgWindow* msgWindow,
   mOuterMimeListener = do_CreateInstance(NS_ENIGMIMELISTENER_CONTRACTID, &rv);
   if (NS_FAILED(rv)) return rv;
 
-  rv = mOuterMimeListener->Init(mFirstPartListener, nsnull,
-                                MAX_HEADER_BYTES, PR_TRUE, PR_FALSE, PR_FALSE);
-  if (NS_FAILED(rv)) return rv;
-
   if (isSubPart)
     mOuterMimeListener->SetSubPartTreatment(PR_TRUE);
+
+  rv = mOuterMimeListener->Init(mFirstPartListener, nsnull,
+                                MAX_HEADER_BYTES, PR_TRUE, PR_FALSE, PR_FALSE);
+
+  if (NS_FAILED(rv)) return rv;
+
   // Initiate asynchronous loading of URI
   rv = channel->AsyncOpen( mOuterMimeListener, nsnull );
   if (NS_FAILED(rv))
@@ -428,7 +433,7 @@ nsEnigMimeVerify::OnStartRequest(nsIRequest *aRequest,
 
   } else if (contentMicalg.EqualsIgnoreCase("pgp-sha256")) {
     hashSymbol = "SHA256";
-    
+
   } else if (contentMicalg.EqualsIgnoreCase("pgp-sha384")) {
     hashSymbol = "SHA384";
 
