@@ -21,7 +21,7 @@
  * Contributor(s):
  *
  * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or 
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
  * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
  * in which case the provisions of the GPL or the LGPL are applicable instead
  * of those above. If you wish to allow use of your version of this file only
@@ -34,10 +34,11 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-// Logging of debug output 
+// Logging of debug output
 // The following define statement should occur before any include statements
 #define FORCE_PR_LOG       /* Allow logging even in release build */
 
+#include "enigmail.h"
 #include "nsEnigMsgCompFields.h"
 #include "nspr.h"
 #include "nsCOMPtr.h"
@@ -46,6 +47,7 @@
 #include "nsFileStream.h"
 #include "nsIThread.h"
 #include "nsIFactory.h"
+#undef MOZILLA_INTERNAL_API
 
 #ifdef PR_LOGGING
 PRLogModuleInfo* gEnigMsgCompFieldsLog = NULL;
@@ -88,9 +90,9 @@ nsEnigMsgCompFields::nsEnigMsgCompFields()
 
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigMsgCompFields:: <<<<<<<<< CTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  rv = ENIG_GET_THREAD(myThread);
+  DEBUG_LOG(("nsEnigMsgCompFields:: <<<<<<<<< CTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 }
 
@@ -100,9 +102,9 @@ nsEnigMsgCompFields::~nsEnigMsgCompFields()
   nsresult rv;
 #ifdef FORCE_PR_LOG
   nsCOMPtr<nsIThread> myThread;
-  rv = nsIThread::GetCurrent(getter_AddRefs(myThread));
-  DEBUG_LOG(("nsEnigMsgCompFields:: >>>>>>>>> DTOR(%x): myThread=%x\n",
-         (int) this, (int) myThread.get()));
+  rv = ENIG_GET_THREAD(myThread);
+  DEBUG_LOG(("nsEnigMsgCompFields:: >>>>>>>>> DTOR(%p): myThread=%p\n",
+         this, myThread.get()));
 #endif
 
 }
