@@ -71,17 +71,30 @@ var gSearchInput = null;
 
 
 function enigmailKeyManagerLoad() {
-   DEBUG_LOG("enigmailKeyManager.js: Load\n");
-   gUserList = document.getElementById("pgpKeyList");
-   gFilterBox = document.getElementById("filterKey");
-   gClearButton = document.getElementById("clearFilter");
-   gSearchInput = document.getElementById("filterKey");
-   window.enigIpcRequest = null;
-   enigmailBuildList(false);
+  DEBUG_LOG("enigmailKeyManager.js: enigmailKeyManagerLoad\n");
+  gUserList = document.getElementById("pgpKeyList");
+  gFilterBox = document.getElementById("filterKey");
+  gClearButton = document.getElementById("clearFilter");
+  gSearchInput = document.getElementById("filterKey");
+  window.enigIpcRequest = null;
+
+  document.getElementById("statusText").value = EnigGetString("keyMan.loadingKeys");
+  document.getElementById("progressBar").removeAttribute("collapsed");
+  window.setTimeout(loadkeyList, 100);
+}
+
+
+function loadkeyList() {
+  DEBUG_LOG("enigmailKeyManager.js: loadkeyList\n");
+
+  enigmailBuildList(false);
+  document.getElementById("statusText").value=" ";
+  document.getElementById("progressBar").setAttribute("collapsed", "true");
 }
 
 
 function enigmailRefreshKeys() {
+  DEBUG_LOG("enigmailKeyManager.js: enigmailRefreshKeys\n");
   var keyList = enigmailGetSelectedKeys();
   gEnigLastSelectedKeys = [];
   for (var i=0; i<keyList.length; i++) {
@@ -97,8 +110,7 @@ function enigmailRefreshKeys() {
 
 
 function enigmailBuildList(refresh) {
-  DEBUG_LOG("enigmailUserSelection.js: enigmailBuildList\n");
-
+  DEBUG_LOG("enigmailKeyManager.js: enigmailBuildList\n");
   var keyListObj = {};
 
   EnigLoadKeyList(refresh, keyListObj);
@@ -130,7 +142,6 @@ function enigmailBuildList(refresh) {
     if (treeItem)
       treeChildren.appendChild(treeItem);
   }
-  gUserList.appendChild(treeChildren);
   
   // select last selected key
   if (selectedItems.length>0) {
@@ -301,11 +312,11 @@ function enigmailKeyMenu() {
   var keyList = enigmailGetSelectedKeys();
   if (keyList.length == 1 && gKeyList[keyList[0]].secretAvailable) {
     document.getElementById("bcRevoke").removeAttribute("disabled");
-    document.getElementById("bcManageUid").removeAttribute("disabled");
+    document.getElementById("bcEditKey").removeAttribute("disabled");
   }
   else {
     document.getElementById("bcRevoke").setAttribute("disabled", "true");
-    document.getElementById("bcManageUid").setAttribute("disabled", "true");
+    document.getElementById("bcEditKey").setAttribute("disabled", "true");
   }
   
   if (keyList.length == 1 && gKeyList[keyList[0]].photoAvailable) {
@@ -336,7 +347,7 @@ function enigmailKeyMenu() {
   if (keyList.length == 1) {
     document.getElementById("bcSignKey").removeAttribute("disabled");
     document.getElementById("bcViewSig").removeAttribute("disabled");
-    document.getElementById("bcKeyDetails").removeAttribute("disabled");
+    document.getElementById("bcOneKey").removeAttribute("disabled");
     document.getElementById("bcDeleteKey").removeAttribute("disabled");
     document.getElementById("bcNoKey").removeAttribute("disabled");
   }
@@ -350,7 +361,7 @@ function enigmailKeyMenu() {
     }
     document.getElementById("bcSignKey").setAttribute("disabled", "true");
     document.getElementById("bcViewSig").setAttribute("disabled", "true");
-    document.getElementById("bcKeyDetails").setAttribute("disabled", "true");
+    document.getElementById("bcOneKey").setAttribute("disabled", "true");
     document.getElementById("bcDeleteKey").setAttribute("disabled", "true");
   }
 }
@@ -731,11 +742,12 @@ function enigmailListSig() {
 function enigmailManageUids() {
   var keyList = enigmailGetSelectedKeys();
   var inputObj = {
-    keyId: keyList[0]
+    keyId: keyList[0],
+    ownKey: gKeyList[keyList[0]].secretAvailable
   };
 
   window.openDialog("chrome://enigmail/content/enigmailManageUidDlg.xul",
-        "", "dialog,modal,centerscreen,resizable", inputObj);
+        "", "dialog,modal,centerscreen,resizable=yes", inputObj);
   enigmailRefreshKeys();
 }
 
