@@ -479,7 +479,7 @@ function enigMessageDecrypt(event, isAuto) {
 
   if (EnigGetPref("parseAllHeaders")) {
     var showHeaders = 0;
-    
+
     try {
       showHeaders = gEnigPrefRoot.getIntPref("mail.show_headers");
     } catch (ex) {
@@ -532,7 +532,7 @@ function enigMessageDecrypt(event, isAuto) {
     }
 
   }
-  
+
   var contentType = "";
   var contentEncoding = "";
   var xEnigmailVersion = "";
@@ -544,16 +544,16 @@ function enigMessageDecrypt(event, isAuto) {
   }
 
   var enigmailSvc;
-    
+
   if (isAuto && (! EnigGetPref("autoDecrypt"))) {
     var signedMsg = ((contentType.search(/^multipart\/signed(;|$)/i) == 0) && (contentType.search(/application\/pgp-signature/i)>0));
     var encrypedMsg = ((contentType.search(/^multipart\/encrypted(;|$)/i) == 0) && (contentType.search(/application\/pgp-encrypted/i)>0));
-    if (embeddedSigned || embeddedEncrypted || 
+    if (embeddedSigned || embeddedEncrypted ||
         encrypedMsg || signedMsg) {
       enigmailSvc = GetEnigmailSvc();
       if (!enigmailSvc)
         return;
-        
+
       if ((!enigmailSvc.mimeInitialized() && encrypedMsg) || signedMsg ||
           ((!encrypedMsg) && (embeddedSigned || embeddedEncrypted))) {
         enigUpdateHdrIcons(ENIG_POSSIBLE_PGPMIME, 0, "", "", "", EnigGetString("possiblyPgpMime"));
@@ -561,7 +561,7 @@ function enigMessageDecrypt(event, isAuto) {
     }
     return;
   }
-  
+
   EnigShowHeadersAll(false);
 
   if (((contentType.search(/^multipart\/encrypted(;|$)/i) == 0) ||
@@ -633,7 +633,7 @@ function enigMessageDecrypt(event, isAuto) {
       const ENIG_ENIGMIMEVERIFY_CONTRACTID = "@mozilla.org/enigmail/mime-verify;1";
       var verifier = Components.classes[ENIG_ENIGMIMEVERIFY_CONTRACTID].createInstance(Components.interfaces.nsIEnigMimeVerify);
 
-      verifier.init(mailNewsUrl, msgWindow, msgUriSpec,
+      verifier.init(window, mailNewsUrl, msgWindow, msgUriSpec,
                     true, enableSubpartTreatment);
 
       return;
@@ -765,6 +765,10 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
     exitCode = exitCodeObj.value;
     newSignature = signatureObj.value;
 
+    if (plainText == "" && exitCode ==0) {
+      plainText = " ";
+    }
+
     statusFlags = statusFlagsObj.value;
 
     DEBUG_LOG("enigmailMessengerOverlay.js: enigMessageParseCallback: newSignature='"+newSignature+"'\n");
@@ -780,7 +784,20 @@ function enigMessageParseCallback(msgText, contentEncoding, charset, interactive
 
   enigUpdateHdrIcons(exitCode, statusFlags, keyIdObj.value, userIdObj.value, sigDetailsObj.value, errorMsg);
 
-  if (statusFlags & (nsIEnigmail.BAD_SIGNATURE | nsIEnigmail.BAD_ARMOR)) {
+  var noSecondTry = nsIEnigmail.GOOD_SIGNATURE |
+        nsIEnigmail.EXPIRED_SIGNATURE |
+        nsIEnigmail.EXPIRED_KEY_SIGNATURE |
+        nsIEnigmail.EXPIRED_KEY |
+        nsIEnigmail.REVOKED_KEY |
+        nsIEnigmail.NO_PUBKEY |
+        nsIEnigmail.NO_SECKEY |
+        nsIEnigmail.IMPORTED_KEY |
+        nsIEnigmail.MISSING_PASSPHRASE |
+        nsIEnigmail.BAD_PASSPHRASE |
+        nsIEnigmail.DECRYPTION_OKAY |
+        nsIEnigmail.OVERFLOWED;
+
+  if ((exitCode !=0) && (! (statusFlags & noSecondTry))) {
     // Bad signature/armor
     if (retry) {
       // Try to verify signature by accessing raw message text directly
@@ -1487,7 +1504,7 @@ function enigHandleAttachmentSel(actionType) {
 
 function enigHandleAttachment(actionType, anAttachment) {
   DEBUG_LOG("enigmailMessengerOverlay.js: enigHandleAttachment: actionType="+actionType+", anAttachment(url)="+anAttachment.url+"\n");
- 
+
   var ipcBuffer = Components.classes[ENIG_IPCBUFFER_CONTRACTID].createInstance(Components.interfaces.nsIIPCBuffer);
 
   var argumentsObj = { actionType: actionType,
@@ -1581,7 +1598,7 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
   }
 
   exitStatus=enigmailSvc.decryptAttachment(window, outFile.path,
-                                callbackArg.attachment.displayName, 
+                                callbackArg.attachment.displayName,
                                 callbackArg.ipcBuffer,
                                 exitCodeObj, statusFlagsObj,
                                 errorMsgObj);
@@ -1618,7 +1635,7 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
         try {
           var extAppLauncher = Components.classes[ENIG_MIME_CONTRACTID].getService(Components.interfaces.nsPIExternalAppLauncher);
           extAppLauncher.deleteTemporaryFileOnExit(outFile);
-  
+
           var mimeService = Components.classes[ENIG_MIME_CONTRACTID].getService(Components.interfaces.nsIMIMEService);
           var fileMimeType = mimeService.GetTypeFromFile(outFile);
           var fileMimeInfo = mimeService.GetFromTypeAndExtension(fileMimeType, fileExt);
@@ -1658,7 +1675,7 @@ function enigDecryptAttachmentCallback(callbackArg, ctxt) {
           return;
         }
       }
-  
+
       // open the attachment using an external application
       enigLoadExternalURL(outFileUri.asciiSpec);
     }
