@@ -61,17 +61,23 @@ var gEnigEnableRules = null;
 
 if (typeof(GenericSendMessage)=="function") {
   // replace GenericSendMessage with our own version
+
   var origGenericSendMessage = GenericSendMessage;
   GenericSendMessage = function (msgType) {
     enigGenericSendMessage(msgType);
   }
 
+  
   window.addEventListener("load", enigMsgComposeStartup, false);
 
   // Handle recycled windows
   window.addEventListener('compose-window-close', enigMsgComposeClose, true);
   window.addEventListener('compose-window-reopen', enigMsgComposeReopen, true);
 
+  /*
+    // Handle message sending (in future)
+    window.addEventListener('compose-send-message', enigMsgComposeSendMsg, true);
+  */
 }
 else {
   EnigAlert("WARNING:\n\nCannot hook message sending -- you will not be able to send OpenPGP messages!");
@@ -1031,7 +1037,7 @@ function enigEncryptMsg(msgSendType) {
      }
 
      var bucketList = document.getElementById("attachmentBucket");
-     var hasAttachments = bucketList && bucketList.hasChildNodes();
+     var hasAttachments = ((bucketList && bucketList.hasChildNodes()) || gMsgCompose.compFields.attachVCard);
 
      DEBUG_LOG("enigmailMsgComposeOverlay.js: hasAttachments = "+hasAttachments+"\n");
 
@@ -1048,7 +1054,8 @@ function enigEncryptMsg(msgSendType) {
         inputObj = new Object();
         inputObj.pgpMimePossible = (usePGPMimeOption >= PGP_MIME_POSSIBLE);
         inputObj.inlinePossible = (sendFlags & ENIG_ENCRYPT); // makes no sense for sign only!
-
+        inputObj.restrictedScenario = false;
+        
         // determine if attachments are all local (currently the only
         // supported kind of attachments)
         var node = bucketList.firstChild;
@@ -1061,8 +1068,21 @@ function enigEncryptMsg(msgSendType) {
 
         if (inputObj.pgpMimePossible || inputObj.inlinePossible) {
           resultObj = new Object();
-          resultObj.selected = -1;
-          window.openDialog("chrome://enigmail/content/enigmailAttachmentsDialog.xul","", "dialog,modal,centerscreen", inputObj, resultObj);
+          resultObj.selected = EnigGetPref("encryptAttachments");
+          
+          //skip or not
+          var skipCheck=EnigGetPref("encryptAttachmentsSkipDlg");
+          if (skipCheck == 1) {
+            if ((resultObj.selected == 2 && inputObj.pgpMimePossible == false) || (resultObj.selected == 1 && inputObj.inlinePossible == false)) {
+              //add var to disable remember box since we're dealing with restricted scenarios...
+              inputObj.restrictedScenario = true;
+              resultObj.selected = -1;
+              window.openDialog("chrome://enigmail/content/enigmailAttachmentsDialog.xul","", "dialog,modal,centerscreen", inputObj, resultObj);
+            }
+          } else {
+            resultObj.selected = -1;
+            window.openDialog("chrome://enigmail/content/enigmailAttachmentsDialog.xul","", "dialog,modal,centerscreen", inputObj, resultObj);
+          }
           if (resultObj.selected < 0) {
             // dialog cancelled
             window.cancelSendMessage=true;
@@ -1135,186 +1155,22 @@ function enigEncryptMsg(msgSendType) {
 
        DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: securityInfo = "+newSecurityInfo+"\n");
 
-     } else if (!gEnigProcessed && (sendFlags & ENIG_ENCRYPT_OR_SIGN)) {
-
-       if (gMsgCompose.composeHTML) {
-         var errMsg = EnigGetString("hasHTML");
-
-         EnigAlertCount("composeHtmlAlertCount", errMsg);
-       }
-
-       try {
-         var convert = DetermineConvertibility();
-         if (convert == nsIMsgCompConvertible.No) {
-           if (!EnigConfirm(EnigGetString("strippingHTML"))) {
-             window.cancelSendMessage=true;
-             return;
-           }
-         }
-       } catch (ex) {
-       }
-
-       try {
-          if (gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
-              if (EnigConfirmPref(EnigGetString("quotedPrintableWarn"), "quotedPrintableWarn")) {
-                gEnigPrefRoot.setBoolPref("mail.strictly_mime", false);
-              }
-          }
-       } catch (ex) {}
-
-
-       var sendFlowed;
-       try {
-         sendFlowed = gEnigPrefRoot.getBoolPref("mailnews.send_plaintext_flowed");
-       } catch (ex) {
-         sendFlowed = true;
-       }
-       var encoderFlags = EnigOutputFormatted | EnigOutputLFLineBreak;
-
-       var wrapWidth=72;
-       if (gMsgCompose.composeHTML) {
-          // enforce line wrapping here
-          // otherwise the message isn't signed correctly
-          try {
-            wrapWidth = gEnigPrefRoot.getIntPref("editor.htmlWrapColumn");
-
-            if (wrapWidth<68) {
-              if (EnigConfirm(EnigGetString("minimalLineWrapping", wrapWidth))) {
-                gEnigPrefRoot.setIntPref("editor.htmlWrapColumn", 68)
-              }
-            }
-            if (!(sendFlags & ENIG_ENCRYPT) && EnigGetPref("wrapHtmlBeforeSend")) {
-              var editor = gMsgCompose.editor.QueryInterface(nsIPlaintextEditorMail);
-              editor.wrapWidth=wrapWidth-2; // prepare for the worst case: a 72 char's long line starting with '-'
-              editor.rewrap(false);
-            }
-          }
-          catch (ex) {}
-       }
-       else {
-          try {
-            wrapWidth = gEnigPrefRoot.getIntPref("mailnews.wraplength");
-            if (wrapWidth<68) {
-              if (EnigConfirm(EnigGetString("minimalLineWrapping", wrapWidth))) {
-                gEnigPrefRoot.setIntPref("mailnews.wraplength", 68)
-              }
-            }
-          }
-          catch (ex) {}
-      }
-
-
-       // Get plain text
-       // (Do we need to set the nsIDocumentEncoder::* flags?)
-       var origText = EnigEditorGetContentsAs("text/plain",
-                                                     encoderFlags);
-
-       // Copy plain text for possible escaping
-       var escText = origText;
-
-       if (sendFlowed && !(sendFlags & ENIG_ENCRYPT)) {
-         // Prevent space stuffing a la RFC 2646 (format=flowed).
-
-         //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText["+encoderFlags+"] = '"+escText+"'\n");
-
-         // MULTILINE MATCHING ON
-         RegExp.multiline = true;
-
-         escText = escText.replace(/^From /g, "~From ");
-         escText = escText.replace(/^>/g, "|");
-         escText = escText.replace(/^[ \t]+$/g, "");
-         escText = escText.replace(/^ /g, "~ ");
-
-         // MULTILINE MATCHING OFF
-         RegExp.multiline = false;
-
-         //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText = '"+escText+"'\n");
-         // Replace plain text and get it again
-         enigReplaceEditorText(escText);
-
-         escText = EnigEditorGetContentsAs("text/plain", encoderFlags);
-       }
-
-       // Replace plain text and get it again (to avoid linewrapping problems)
-       enigReplaceEditorText(escText);
-
-       escText = EnigEditorGetContentsAs("text/plain", encoderFlags);
-
-       //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText["+encoderFlags+"] = '"+escText+"'\n");
-
-       if (!escText) {
-         // No encryption or signing for null text
-         sendFlags &= ~ENIG_ENCRYPT_OR_SIGN;
-
-       } else {
-         // Encrypt plaintext
-         var charset = EnigEditorGetCharset();
-         DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: charset="+charset+"\n");
-
-         // Encode plaintext to charset from unicode
-         var plainText = (sendFlags & ENIG_ENCRYPT)
-                         ? EnigConvertFromUnicode(origText, charset)
-                         : EnigConvertFromUnicode(escText, charset);
-
-         exitCodeObj    = new Object();
-         statusFlagsObj = new Object();
-         errorMsgObj    = new Object();
-
-         var cipherText = enigmailSvc.encryptMessage(window,uiFlags, plainText,
-                                                fromAddr, toAddr, sendFlags,
-                                                exitCodeObj, statusFlagsObj,
-                                                errorMsgObj);
-
-         var exitCode = exitCodeObj.value;
-
-         //DEBUG_LOG("enigmailMsgComposeOverlay.js: cipherText = '"+cipherText+"'\n");
-         if (cipherText && (exitCode == 0)) {
-           // Encryption/signing succeeded; overwrite plaintext
-
-           if ( (sendFlags & ENIG_ENCRYPT) && charset &&
-                (charset.search(/^us-ascii$/i) != 0) ) {
-             // Add Charset armor header for encrypted blocks
-             cipherText = cipherText.replace(/(-----BEGIN PGP MESSAGE----- *)(\r?\n)/, "$1$2Charset: "+charset+"$2");
-           }
-
-           // Decode ciphertext from charset to unicode and overwrite
-           enigReplaceEditorText( EnigConvertToUnicode(cipherText, charset) );
-
-           // Save original text (for undo)
-           gEnigProcessed = {"origText":origText, "charset":charset};
-
-         } else {
-           // Restore original text
-           enigReplaceEditorText(origText);
-
-           if (sendFlags & ENIG_ENCRYPT_OR_SIGN) {
-             // Encryption/signing failed
-             EnigAlert(EnigGetString("sendAborted")+errorMsgObj.value);
-             window.cancelSendMessage=true;
-             return;
-           }
-         }
-
-         if (inlineEncAttach) {
-            // encrypt attachments
-            gEnigModifiedAttach = new Array();
-            exitCode = enigEncryptAttachments(bucketList, gEnigModifiedAttach,
-                                    window, uiFlags, fromAddr, toAddr, sendFlags,
-                                    errorMsgObj);
-            if (exitCode != 0) {
-              gEnigModifiedAttach = null;
-              if (errorMsgObj.value) {
-                EnigAlert(EnigGetString("sendAborted")+errorMsgObj.value);
-              }
-              else {
-                EnigAlert(EnigGetString("sendAborted")+"an internal error has occurred");
-              }
-              if (gEnigProcessed)
-                enigUndoEncryption();
-              window.cancelSendMessage=true;
-              return;
-            }
-         }
+     }
+     else if (!gEnigProcessed && (sendFlags & ENIG_ENCRYPT_OR_SIGN)) {
+       // use inline PGP
+       
+       var sendInfo = {
+         sendFlags: sendFlags,
+         inlineEncAttach: inlineEncAttach,
+         fromAddr: fromAddr,
+         toAddr: toAddr,
+         uiFlags: uiFlags,
+         bucketList: bucketList
+       };
+       
+       if (! enigEncryptInline(sendInfo)) {
+         window.cancelSendMessage=true;
+         return;
        }
      }
 
@@ -1383,6 +1239,187 @@ function enigEncryptMsg(msgSendType) {
   }
 }
 
+function enigEncryptInline(sendInfo) {
+  // sign/encrpyt message using inline-PGP
+
+  var enigmailSvc = GetEnigmailSvc();
+  if (! enigmailSvc) return false;
+  
+  if (gMsgCompose.composeHTML) {
+    var errMsg = EnigGetString("hasHTML");
+    EnigAlertCount("composeHtmlAlertCount", errMsg);
+  }
+
+  try {
+    var convert = DetermineConvertibility();
+    if (convert == nsIMsgCompConvertible.No) {
+      if (!EnigConfirm(EnigGetString("strippingHTML"))) {
+        return false;
+      }
+    }
+  } catch (ex) {}
+
+  try {
+  if (gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
+    if (EnigConfirmPref(EnigGetString("quotedPrintableWarn"), "quotedPrintableWarn")) {
+      gEnigPrefRoot.setBoolPref("mail.strictly_mime", false);
+    }
+  }
+  } catch (ex) {}
+
+
+  var sendFlowed;
+  try {
+    sendFlowed = gEnigPrefRoot.getBoolPref("mailnews.send_plaintext_flowed");
+  } catch (ex) {
+    sendFlowed = true;
+  }
+  var encoderFlags = EnigOutputFormatted | EnigOutputLFLineBreak;
+
+  var wrapWidth=72;
+  if (gMsgCompose.composeHTML) {
+    // enforce line wrapping here
+    // otherwise the message isn't signed correctly
+    try {
+      wrapWidth = gEnigPrefRoot.getIntPref("editor.htmlWrapColumn");
+
+      if (wrapWidth<68) {
+        if (EnigConfirm(EnigGetString("minimalLineWrapping", wrapWidth))) {
+          gEnigPrefRoot.setIntPref("editor.htmlWrapColumn", 68)
+        }
+      }
+      if (!(sendInfo.sendFlags & ENIG_ENCRYPT) && EnigGetPref("wrapHtmlBeforeSend")) {
+        var editor = gMsgCompose.editor.QueryInterface(nsIPlaintextEditorMail);
+        editor.wrapWidth=wrapWidth-2; // prepare for the worst case: a 72 char's long line starting with '-'
+        editor.rewrap(false);
+      }
+    }
+    catch (ex) {}
+  }
+  else {
+    try {
+      wrapWidth = gEnigPrefRoot.getIntPref("mailnews.wraplength");
+      if (wrapWidth<68) {
+        if (EnigConfirm(EnigGetString("minimalLineWrapping", wrapWidth))) {
+          gEnigPrefRoot.setIntPref("mailnews.wraplength", 68)
+        }
+      }
+    }
+    catch (ex) {}
+  }
+
+  var exitCodeObj    = new Object();
+  var statusFlagsObj = new Object();
+  var errorMsgObj    = new Object();
+
+
+  // Get plain text
+  // (Do we need to set the nsIDocumentEncoder.* flags?)
+  var origText = EnigEditorGetContentsAs("text/plain",
+                                         encoderFlags);
+
+  if (origText.length > 0) {
+    // Sign/encrypt body text
+    
+    var escText = origText; // Copy plain text for possible escaping
+
+    if (sendFlowed && !(sendInfo.sendFlags & ENIG_ENCRYPT)) {
+      // Prevent space stuffing a la RFC 2646 (format=flowed).
+
+      //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText["+encoderFlags+"] = '"+escText+"'\n");
+
+      // MULTILINE MATCHING ON
+      RegExp.multiline = true;
+
+      escText = escText.replace(/^From /g, "~From ");
+      escText = escText.replace(/^>/g, "|");
+      escText = escText.replace(/^[ \t]+$/g, "");
+      escText = escText.replace(/^ /g, "~ ");
+
+      // MULTILINE MATCHING OFF
+      RegExp.multiline = false;
+
+      //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText = '"+escText+"'\n");
+      // Replace plain text and get it again
+      enigReplaceEditorText(escText);
+
+      escText = EnigEditorGetContentsAs("text/plain", encoderFlags);
+    }
+
+    // Replace plain text and get it again (to avoid linewrapping problems)
+    enigReplaceEditorText(escText);
+
+    escText = EnigEditorGetContentsAs("text/plain", encoderFlags);
+
+    //DEBUG_LOG("enigmailMsgComposeOverlay.js: escText["+encoderFlags+"] = '"+escText+"'\n");
+
+    // Encrypt plaintext
+    var charset = EnigEditorGetCharset();
+    DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: charset="+charset+"\n");
+
+    // Encode plaintext to charset from unicode
+    var plainText = (sendInfo.sendFlags & ENIG_ENCRYPT)
+                   ? EnigConvertFromUnicode(origText, charset)
+                   : EnigConvertFromUnicode(escText, charset);
+
+    var cipherText = enigmailSvc.encryptMessage(window, sendInfo.uiFlags, plainText,
+                                          sendInfo.fromAddr, sendInfo.toAddr, sendInfo.sendFlags,
+                                          exitCodeObj, statusFlagsObj,
+                                          errorMsgObj);
+
+    var exitCode = exitCodeObj.value;
+
+    //DEBUG_LOG("enigmailMsgComposeOverlay.js: cipherText = '"+cipherText+"'\n");
+    if (cipherText && (exitCode == 0)) {
+     // Encryption/signing succeeded; overwrite plaintext
+
+     if ( (sendInfo.sendFlags & ENIG_ENCRYPT) && charset &&
+          (charset.search(/^us-ascii$/i) != 0) ) {
+       // Add Charset armor header for encrypted blocks
+       cipherText = cipherText.replace(/(-----BEGIN PGP MESSAGE----- *)(\r?\n)/, "$1$2Charset: "+charset+"$2");
+     }
+
+     // Decode ciphertext from charset to unicode and overwrite
+     enigReplaceEditorText( EnigConvertToUnicode(cipherText, charset) );
+
+     // Save original text (for undo)
+     gEnigProcessed = {"origText":origText, "charset":charset};
+
+    }
+    else {
+      // Restore original text
+      enigReplaceEditorText(origText);
+
+      if (sendInfo.sendFlags & ENIG_ENCRYPT_OR_SIGN) {
+        // Encryption/signing failed
+        EnigAlert(EnigGetString("sendAborted")+errorMsgObj.value);
+        return false;
+      }
+    }
+  }
+
+  if (sendInfo.inlineEncAttach) {
+    // encrypt attachments
+    gEnigModifiedAttach = new Array();
+    exitCode = enigEncryptAttachments(sendInfo.bucketList, gEnigModifiedAttach,
+                            window, sendInfo.uiFlags, sendInfo.fromAddr, sendInfo.toAddr,
+                            sendInfo.sendFlags, errorMsgObj);
+    if (exitCode != 0) {
+      gEnigModifiedAttach = null;
+      if (errorMsgObj.value) {
+        EnigAlert(EnigGetString("sendAborted")+errorMsgObj.value);
+      }
+      else {
+        EnigAlert(EnigGetString("sendAborted")+"an internal error has occurred");
+      }
+      if (gEnigProcessed) enigUndoEncryption();
+      return false;
+    }
+  }
+  return true;
+}
+
+
 function enigMessageSendCheck() {
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigMessageSendCheck\n");
 
@@ -1472,35 +1509,23 @@ function enigGenericSendMessage( msgType )
       msgCompFields.subject = subject;
       Attachments2CompFields(msgCompFields);
 
-      var event = document.createEvent('Events');
-      event.initEvent('compose-send-message', false, true);
-      document.getElementById("msgcomposeWindow").dispatchEvent(event);
-
-/////////////////////////////////////////////////////////////////////////
-// MODIFICATION
-// Call the following function from our version of the function
-// GenericSendMessage from the file MsgComposeCommands.js
-// (after the calls to Recipients2CompFields and Attachements2CompFields)
-/////////////////////////////////////////////////////////////////////////
-      enigModifyCompFields(msgCompFields);
-/////////////////////////////////////////////////////////////////////////
-
       if (msgType == nsIMsgCompDeliverMode.Now || msgType == nsIMsgCompDeliverMode.Later)
       {
         //Do we need to check the spelling?
-        if (sPrefs.getBoolPref("mail.SpellCheckBeforeSend")){
-        //We disable spellcheck for the following -subject line, attachment pane, identity and addressing widget
-        //therefore we need to explicitly focus on the mail body when we have to do a spellcheck.
+        if (sPrefs.getBoolPref("mail.SpellCheckBeforeSend"))
+        {
+          //We disable spellcheck for the following -subject line, attachment pane, identity and addressing widget
+          //therefore we need to explicitly focus on the mail body when we have to do a spellcheck.
           window.content.focus();
           window.cancelSendMessage = false;
           try {
             window.openDialog("chrome://editor/content/EdSpellCheck.xul", "_blank",
-                    "chrome,close,titlebar,modal", true, true, false);
+                    "chrome,close,titlebar,modal", true, true);
           }
           catch(ex){}
           if(window.cancelSendMessage)
             return;
-        }            
+         }
 
         //Check if we have a subject, else ask user for confirmation
         
@@ -1536,84 +1561,131 @@ function enigGenericSendMessage( msgType )
           }
         }
 
-        // Before sending the message, check what to do with HTML message, eventually abort.
-        var convert = DetermineConvertibility();
-        var action = DetermineHTMLAction(convert);
-        if (action == nsIMsgCompSendFormat.AskUser)
-        {
-          var recommAction = convert == nsIMsgCompConvertible.No
-                         ? nsIMsgCompSendFormat.AskUser
-                         : nsIMsgCompSendFormat.PlainText;
-          var result2 = {action:recommAction,
-                        convertible:convert,
-                        abort:false};
-          window.openDialog("chrome://messenger/content/messengercompose/askSendFormat.xul",
-                            "askSendFormatDialog", "chrome,modal,titlebar,centerscreen",
-                            result2);
-          if (result2.abort)
-            return;
-          action = result2.action;
-        }
-        switch (action)
-        {
-        case nsIMsgCompSendFormat.PlainText:
-          msgCompFields.forcePlainText = true;
-          msgCompFields.useMultipartAlternative = false;
-          break;
-        case nsIMsgCompSendFormat.HTML:
-          msgCompFields.forcePlainText = false;
-          msgCompFields.useMultipartAlternative = false;
-          break;
-        case nsIMsgCompSendFormat.Both:
-          msgCompFields.forcePlainText = false;
-          msgCompFields.useMultipartAlternative = true;
-          break;
-        default: 
-          ERROR_LOG("\###SendMessage Error: invalid action value\n");
+          // check if the user tries to send a message to a newsgroup through a mail account
+          var currentAccountKey = getCurrentAccountKey();
+          var account = gAccountManager.getAccount(currentAccountKey);
+          if (!account)
+          {
+            throw "UNEXPECTED: currentAccountKey '" + currentAccountKey +
+                "' has no matching account!";
+          }
+          var servertype = account.incomingServer.type;
+
+          if (servertype != "nntp" && msgCompFields.newsgroups != "")
+          {
+            // default to ask user if the pref is not set
+            var dontAskAgain = sPrefs.getBoolPref("mail.compose.dontWarnMail2Newsgroup");
+
+            if (!dontAskAgain)
+            {
+              var checkbox = {value:false};
+              var okToProceed = gPromptService.confirmCheck(window,
+                                                            sComposeMsgsBundle.getString("sendMsgTitle"),
+                                                            sComposeMsgsBundle.getString("recipientDlogMessage"),
+                                                            sComposeMsgsBundle.getString("CheckMsg"), checkbox);
+
+              if (!okToProceed)
+                return;
+
+              if (checkbox.value)
+                sPrefs.setBoolPref(kDontAskAgainPref, true);
+            }
+
+            // remove newsgroups to prevent news_p to be set
+            // in nsMsgComposeAndSend::DeliverMessage()
+            msgCompFields.newsgroups = "";
+          }
+
+          // Before sending the message, check what to do with HTML message, eventually abort.
+          var convert = DetermineConvertibility();
+          var action = DetermineHTMLAction(convert);
+         // check if e-mail addresses are complete, in case user
+         // has turned off autocomplete to local domain.
+         if (!CheckValidEmailAddress(msgCompFields.to, msgCompFields.cc, msgCompFields.bcc))
           return;
-        }
+
+          if (action == nsIMsgCompSendFormat.AskUser)
+          {
+            var recommAction = convert == nsIMsgCompConvertible.No
+                           ? nsIMsgCompSendFormat.AskUser
+                           : nsIMsgCompSendFormat.PlainText;
+            var result2 = {action:recommAction,
+                          convertible:convert,
+                          abort:false};
+            window.openDialog("chrome://messenger/content/messengercompose/askSendFormat.xul",
+                              "askSendFormatDialog", "chrome,modal,titlebar,centerscreen",
+                              result2);
+            if (result2.abort)
+              return;
+            action = result2.action;
+          }
+
+          // we will remember the users "send format" decision
+          // in the address collector code (see nsAbAddressCollecter::CollectAddress())
+          // by using msgCompFields.forcePlainText and msgCompFields.useMultipartAlternative
+          // to determine the nsIAbPreferMailFormat (unknown, plaintext, or html)
+          // if the user sends both, we remember html.
+
+          switch (action)
+          {
+            case nsIMsgCompSendFormat.PlainText:
+              msgCompFields.forcePlainText = true;
+              msgCompFields.useMultipartAlternative = false;
+              break;
+            case nsIMsgCompSendFormat.HTML:
+              msgCompFields.forcePlainText = false;
+              msgCompFields.useMultipartAlternative = false;
+              break;
+            case nsIMsgCompSendFormat.Both:
+              msgCompFields.forcePlainText = false;
+              msgCompFields.useMultipartAlternative = true;
+              break;
+             default: dump("\###SendMessage Error: invalid action value\n"); return;
+          }
       }
 
       // hook for extra compose pre-processing
       var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
       observerService.notifyObservers(window, "mail:composeOnSend", null);
-/*
-/////////////////////////////////////////////////////////////////////////
-// MODIFICATION
-// Set the charset from the original text
-// (after setting observerService)
-/////////////////////////////////////////////////////////////////////////
-      if (gEnigProcessed) {
-        // Ensure that original charset is preserved for encrypted messages
-        gMsgCompose.SetDocumentCharset(gEnigProcessed.charset);
 
-      } else {
-/////////////////////////////////////////////////////////////////////////
-// END OF MODIFICATION
-/////////////////////////////////////////////////////////////////////////
-*/
-         // Check if the headers of composing mail can be converted to a mail charset.
-        if (msgType == nsIMsgCompDeliverMode.Now ||
-            msgType == nsIMsgCompDeliverMode.Later ||
-            msgType == nsIMsgCompDeliverMode.Save ||
-            msgType == nsIMsgCompDeliverMode.SaveAsDraft ||
-            msgType == nsIMsgCompDeliverMode.SaveAsTemplate)
+      // Check if the headers of composing mail can be converted to a mail charset.
+      if (msgType == nsIMsgCompDeliverMode.Now ||
+        msgType == nsIMsgCompDeliverMode.Later ||
+        msgType == nsIMsgCompDeliverMode.Save ||
+        msgType == nsIMsgCompDeliverMode.SaveAsDraft ||
+        msgType == nsIMsgCompDeliverMode.AutoSaveAsDraft ||
+        msgType == nsIMsgCompDeliverMode.SaveAsTemplate)
+      {
+        var fallbackCharset = new Object;
+        if (gPromptService &&
+            !gMsgCompose.checkCharsetConversion(getCurrentIdentity(), fallbackCharset))
         {
-          var fallbackCharset = new Object;
-          if (gPromptService &&
-              !gMsgCompose.checkCharsetConversion(getCurrentIdentity(), fallbackCharset))
+          var dlgTitle = sComposeMsgsBundle.getString("initErrorDlogTitle");
+          var dlgText = sComposeMsgsBundle.getString("12553");  // NS_ERROR_MSG_MULTILINGUAL_SEND
+          var result3 = gPromptService.confirmEx(window, dlgTitle, dlgText,
+              (gPromptService.BUTTON_TITLE_IS_STRING * gPromptService.BUTTON_POS_0) +
+              (gPromptService.BUTTON_TITLE_IS_STRING * gPromptService.BUTTON_POS_1) +
+              (gPromptService.BUTTON_TITLE_CANCEL * gPromptService.BUTTON_POS_2),
+              sComposeMsgsBundle.getString('sendInUTF8'),
+              sComposeMsgsBundle.getString('sendAnyway'),
+              null, null, {value:0});
+          switch(result3)
           {
-            var dlgTitle = sComposeMsgsBundle.getString("initErrorDlogTitle");
-            var dlgText = sComposeMsgsBundle.getString("12553");  // NS_ERROR_MSG_MULTILINGUAL_SEND
-            if (!gPromptService.confirm(window, dlgTitle, dlgText))
+            case 0:
+              fallbackCharset.value = "UTF-8";
+              break;
+            case 1:  // send anyway
+              msgCompFields.needToCheckCharset = false;
+              break;
+            case 2:  // cancel
               return;
-            fallbackCharset.value = "UTF-8";
           }
-          if (fallbackCharset &&
-              fallbackCharset.value && fallbackCharset.value != "")
-            gMsgCompose.SetDocumentCharset(fallbackCharset.value);
         }
-//      }
+        if (fallbackCharset &&
+            fallbackCharset.value && fallbackCharset.value != "")
+          gMsgCompose.SetDocumentCharset(fallbackCharset.value);
+      }
+
 
 /////////////////////////////////////////////////////////////////////////
 // MODIFICATION
@@ -1621,21 +1693,29 @@ function enigGenericSendMessage( msgType )
 // GenericSendMessage from the file MsgComposeCommands.js
 // (after having determined HTML convertibility)
 /////////////////////////////////////////////////////////////////////////
-          try {
-            window.cancelSendMessage=false;
-            enigEncryptMsg(msgType);
-            if(window.cancelSendMessage)
-              return;
-          }
-          catch(ex){}
+      try {
+        window.cancelSendMessage=false;
+        enigModifyCompFields(msgCompFields);
+        enigEncryptMsg(msgType);
+        if(window.cancelSendMessage)
+          return;
+      }
+      catch(ex){}
 /////////////////////////////////////////////////////////////////////////
 // END OF MODIFICATION
 /////////////////////////////////////////////////////////////////////////
 
       try {
+
+        // just before we try to send the message, fire off the compose-send-message event for listeners
+        // such as smime so they can do any pre-security work such as fetching certificates before sending
+        var event = document.createEvent('Events');
+        event.initEvent('compose-send-message', false, true);
+        document.getElementById("msgcomposeWindow").dispatchEvent(event);
+
         gWindowLocked = true;
-        CommandUpdate_MsgCompose();
         disableEditableFields();
+        updateComposeItems();
 
         var progress = Components.classes["@mozilla.org/messenger/progress;1"].createInstance(Components.interfaces.nsIMsgProgress);
         if (progress)
@@ -1644,10 +1724,9 @@ function enigGenericSendMessage( msgType )
           gSendOrSaveOperationInProgress = true;
         }
         msgWindow.SetDOMWindow(window);
-        
-        // Mozilla >= 1.7a only
-        gMsgCompose.SendMsg(msgType, getCurrentIdentity(), getCurrentAccountKey(), msgWindow, progress);
-        
+        msgWindow.rootDocShell.allowAuth = true;
+        gMsgCompose.SendMsg(msgType, getCurrentIdentity(), currentAccountKey, msgWindow, progress);
+/*
 /////////////////////////////////////////////////////////////////////////
 // MODIFICATION
 // Call the following function from our version of the function
@@ -1657,12 +1736,16 @@ function enigGenericSendMessage( msgType )
         if (window.enigmailSendFlags & nsIEnigmail.SAVE_MESSAGE) {
           enigUndoEncryption();
         }
+/////////////////////////////////////////////////////////////////////////
+// END OF MODIFICATION
+/////////////////////////////////////////////////////////////////////////
+*/
       }
       catch (ex) {
-        ERROR_LOG("failed to SendMsg: " + ex + "\n");
+        dump("failed to SendMsg: " + ex + "\n");
         gWindowLocked = false;
         enableEditableFields();
-        CommandUpdate_MsgCompose();
+        updateComposeItems();
       }
     }
   }
@@ -1828,8 +1911,6 @@ function enigDecryptQuote(interactive) {
 
   // Determine indentation string
   var indentBegin = docText.substr(0, blockBegin).lastIndexOf("\n");
-  if (indentBegin < 0)
-    return;
   var indentStr = docText.substring(indentBegin+1, blockBegin);
 
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDecryptQuote: indentStr='"+indentStr+"'\n");
@@ -2027,41 +2108,40 @@ function enigDecryptQuote(interactive) {
     replyOnTop = gEnigIdentity.replyOnTop;
   } catch (ex) {}
 
-  if (!indentStr || !quoteElement)
-    replyOnTop = 1;
+  if (!indentStr || !quoteElement) replyOnTop = 1;
 
   DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDecryptQuote: replyOnTop="+replyOnTop+", quoteElement="+quoteElement+"\n");
 
   var nsISelectionController = Components.interfaces.nsISelectionController;
 
-  var selection;
-  if (gEnigEditor.selectionController)
-      selection = gEnigEditor.selectionController.getSelection(nsISelectionController.SELECTION_NORMAL)
-
-  try {
-    var quoteOffset = 0;
-    if (quoteElement)
-      quoteOffset = enigGetChildOffset(quoteElement.parentNode, quoteElement);
-
-    DEBUG_LOG("enigmailMsgComposeOverlay.js: enigDecryptQuote: quoteOffset="+quoteOffset+", selection="+selection+"\n");
+  if (gEnigEditor.selectionController) {
+    var selection = gEnigEditor.selectionController;
+    selection.completeMove(false, false); // go to start;
 
     switch (replyOnTop) {
     case 0:
       // Position after quote
-      if (selection && quoteOffset) {
-          selection.collapse(quoteElement.parentNode, quoteOffset);
+      gEnigEditor.endOfDocument();
+      if (tail) {
+        for (cPos = 0; cPos < tail.length; cPos++) {
+          selection.characterMove(false, false); // move backwards
+        }
       }
       break;
 
     case 2:
       // Select quote
 
-      if (selection && quoteOffset) {
-        selection.collapse(quoteElement.parentNode, quoteOffset-1);
-        selection.extend(quoteElement.parentNode, quoteOffset);
-
-      } else {
-        EnigEditorSelectAll();
+      if (head) {
+        for (cPos = 0; cPos < head.length; cPos++) {
+          selection.characterMove(true, false);
+        }
+      }
+      selection.completeMove(true, true);
+      if (tail) {
+        for (cPos = 0; cPos < tail.length; cPos++) {
+          selection.characterMove(false, true); // move backwards
+        }
       }
       break;
 
@@ -2070,16 +2150,14 @@ function enigDecryptQuote(interactive) {
 
       if (gEnigEditor) {
         gEnigEditor.beginningOfDocument();
-
       }
-
     }
-  } catch (ex) {}
 
-  if (gEnigEditor.selectionController)
-      gEnigEditor.selectionController.scrollSelectionIntoView(nsISelectionController.SELECTION_NORMAL,
-                                     nsISelectionController.SELECTION_ANCHOR_REGION,
-                                     true);
+    gEnigEditor.selectionController.scrollSelectionIntoView(nsISelectionController.SELECTION_NORMAL,
+                                   nsISelectionController.SELECTION_ANCHOR_REGION,
+                                   true);
+  }
+
 }
 
 // Returns offset of child (> 0), or 0, if child not found
@@ -2114,6 +2192,7 @@ function EnigEditorInsertText(plainText) {
 }
 
 function EnigEditorInsertAsQuotation(plainText) {
+  DEBUG_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation\n");
   if (gEnigEditor) {
     var mailEditor;
     try {
@@ -2121,13 +2200,48 @@ function EnigEditorInsertAsQuotation(plainText) {
     } catch (ex) {}
 
     if (!mailEditor)
-      return null;
+      return 0;
 
     DEBUG_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: mailEditor="+mailEditor+"\n");
 
-    return mailEditor.insertAsQuotation(plainText);
+    // use pasteAsQuotation because inertAsQuotation is buggy with TB 1.5
+    var clipBoard = Components.classes[ENIG_CLIPBOARD_CONTRACTID].getService(Components.interfaces.nsIClipboard);
+    // get the clipboard content
+    var transferable = Components.classes[ENIG_TRANSFERABLE_CONTRACTID].createInstance(Components.interfaces.nsITransferable);
+    var xferTypes = [ "text/unicode", "text/html" ];
 
+    for (var i=0; i < xferTypes.length; i++) {
+      transferable.addDataFlavor(xferTypes[i]);
+    }
+    var flavour = {};
+    var data = {};
+    var length = {};
+    try {
+      clipBoard.getData(transferable, clipBoard.kGlobalClipboard);
+      transferable.getAnyTransferData(flavour, data, length);
+    }
+   catch (ex) {
+      ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: getting clipboard failed\n");
+   }
+
+    try {
+      var pasteClipboard;
+
+      // paste the email text
+      pasteClipboard = Components.classes[ENIG_CLIPBOARD_HELPER_CONTRACTID].getService(Components.interfaces.nsIClipboardHelper);
+      pasteClipboard.copyStringToClipboard(plainText, clipBoard.kGlobalClipboard);
+      mailEditor.pasteAsQuotation(clipBoard.kGlobalClipboard);
+
+      data = data.value.QueryInterface(Components.interfaces.nsISupportsString).data;
+      pasteClipboard.copyStringToClipboard(data, clipBoard.kGlobalClipboard);
+   }
+   catch (ex) {
+      ERROR_LOG("enigmailMsgComposeOverlay.js: EnigEditorInsertAsQuotation: (re-)setting clipboard failed\n");
+   }
+
+   return 1;
   }
+  return 0;
 }
 
 
@@ -2245,4 +2359,3 @@ EnigDocStateListener.prototype = {
       gEnigTimeoutID = window.setTimeout(enigDecryptQuote, 10, false);
   }
 }
-
