@@ -653,8 +653,7 @@ function enigmailSearchMissingKeys () {
   };
   var resultObj = new Object();
   
-  window.openDialog("chrome://enigmail/content/enigmailSearchKey.xul",
-        "", "dialog,modal,centerscreen", inputObj, resultObj);
+  EnigDownloadKeys(inputObj, resultObj);
         
   if (resultObj.importedKeys > 0) {
     enigmailRefreshKeys();
