@@ -1,3 +1,36 @@
+/*
+The contents of this file are subject to the Mozilla Public
+License Version 1.1 (the "MPL"); you may not use this file
+except in compliance with the MPL. You may obtain a copy of
+the MPL at http://www.mozilla.org/MPL/
+
+Software distributed under the MPL is distributed on an "AS
+IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
+implied. See the MPL for the specific language governing
+rights and limitations under the MPL.
+
+The Original Code is Enigmail.
+
+The Initial Developer of the Original Code is Ramalingam Saravanan.
+Portions created by Ramalingam Saravanan <svn@xmlterm.org> are
+Copyright (C) 2001 Ramalingam Saravanan. All Rights Reserved.
+
+Contributor(s):
+Patrick Brunschwig <patrick.brunschwig@gmx.net>
+
+Alternatively, the contents of this file may be used under the
+terms of the GNU General Public License (the "GPL"), in which case
+the provisions of the GPL are applicable instead of
+those above. If you wish to allow use of your version of this
+file only under the terms of the GPL and not to allow
+others to use your version of this file under the MPL, indicate
+your decision by deleting the provisions above and replace them
+with the notice and other provisions required by the GPL.
+If you do not delete the provisions above, a recipient
+may use your version of this file under either the MPL or the
+GPL.
+*/
+
 // Uses: chrome://enigmail/content/enigmailCommon.js
 
 // Initialize enigmailCommon
@@ -46,7 +79,7 @@ function prefOnLoad() {
                         gEnigPerRecipientRules);
 
    gMimeHashElement = document.getElementById("mimeHashList");
-   gMimeHashElement.selectedIndex = EnigGetPref("mimeHashAlgorithm");
+   gMimeHashElement.selectedIndex = EnigGetPref("mimeHashAlgorithm")-1;
 
    gSendFlowedElement = document.getElementById("send_plaintext_flowed");
 
@@ -99,7 +132,7 @@ function resetPrefs() {
                       gEnigPerRecipientRules);
                       
 
-  gMimeHashElement.selectedIndex = EnigGetDefaultPref("mimeHashAlgorithm");
+  gMimeHashElement.selectedIndex = EnigGetDefaultPref("mimeHashAlgorithm")-1;
 }
 
 
@@ -114,7 +147,7 @@ function prefOnAccept() {
 
   EnigSetRadioPref("usePGPMimeOption", gUsePGPMimeOptionList);
 
-  EnigSetPref("mimeHashAlgorithm", gMimeHashElement.selectedIndex);
+  EnigSetPref("mimeHashAlgorithm", gMimeHashElement.selectedIndex+1);
 
   EnigSetRadioPref("recipientsSelectionOption", gEnigRecipientsSelectionOptions);
 
